function  [csr, csb] = MG_Wavelets_Complexity( session, params )
%  [csr, csb] = MG_Wavelets_Complexity( session, params )
% get complexity scores, ratio of possible wavelets comperession,
% works with original <session> data.
%
% input:
% session - cell array of MG games, with same number of rounds.
% params - with possible fields:
%   .use_signal - 'Velocity'  or 'Position' (default)
%   .pos_dist_thr (default = 2.0)   - median allowed error of reconstruction
%   .vel_dist_thr (default = 10.0)
%
% 20-07-15: add option to work with  'complexity_by_wavelets_by_energy'
%  . method - 'energy' (default)  or 'thr'
%  . plot_type - 'no' (default), 'pause' or 'save'
%
%   for wavelets functions signal length-need to be exactly 2^N,  we cut to longest possible 2^N.  and average
%   of complexety on the first part (1..2^N) and last part ( [len - 2^N+1].. end)
%
% output:
% csr, csb- Complex Scores for Red or Blue palyers [games, rounds] matrix
% fw_all - all Wavelets vector for analyzing building-blocks
%
% - does not work if has  NaN values in both parts
% - needed in the path = .\Matlab ToolBoxs\Utilities\Wavelets\toolbox ; .\Matlab ToolBoxs\Utilities\Wavelets\

% size of relevant Wavelets
% ====================
% with signals 1..2048  (~40 sec), Wavelets Width was computed from simulation to be:
% 1..8 = ~1000 ( ~0.05 Hz )  // Based on 50 samples-per-second
% 9..16 = ~500 ( ~0.1  Hz )
% 32..64 = 187 ( ~0.25 Hz )
% 65..128 = 97 ( ~0.5 Hz )
% 129..256 = 51 ( ~1 Hz )
% 257..512 = 29 ( ~1.7 Hz )
% 513..1024 = 16 ( ~3.3 Hz )
%

% defaults
if ~exist('params','var'),
    params = [];
end
if ~isfield(params,'use_signal'),
    params.use_signal = 'Position';
end
if ~isfield(params,'pos_dist_thr'),
    params.pos_dist_thr = 2.0;
end
if ~isfield(params,'vel_dist_thr'),
    params.vel_dist_thr = 10.0;
end

params = add_default( params, 'method', 'energy' );
params = add_default( params, 'plot_type', 'no' );

% set distance threshold according according to type of signal (Pos or Vel)
switch params.use_signal,
    case 'Velocity',
        params.dist_thr = params.vel_dist_thr;
    case 'Position'
        params.dist_thr = params.pos_dist_thr;
    otherwise,
        error('mmm? stragne .use_signal')
end

for i = 1 : length( session ),
    for j = 1 : length( session{i}.trials ),
        if isempty( session{i}.trials{j} ), continue, end
        
        display( sprintf(  ' game = %d, round = %d', i, j ) );
        
        params.lbl = sprintf('%d_%d_R',i,j);
        csr(i,j) = MG_Wavelets_Complexity_Do_One( session{i}.trials{j}(:,2), params );
        
        params.lbl = sprintf('%d_%d_B',i,j);
        csb(i,j) = MG_Wavelets_Complexity_Do_One( session{i}.trials{j}(:,3), params );  %#ok<*AGROW>
    end
end