function cr = MG_Wavelets_Complexity_Do_One(x, params)
% MG_WAVELETS_COMPLEXITY_DO_ONE - inner function for  MG_Wavelets_Complexity
% cr = MG_Wavelets_Complexity_Do_One(x, params) - 
% input:
% x - position segment
% params - see MG_Wavelets_Complexity
%
% output:
% cr - wavlet complexity ratio [0..1]
%

% 23-Nov-2016: Defaults from MG_Wavelets_Complexity, repeated here for a direct call.
% need to change in both places if changed.
if ~exist('params','var'),   params = [];  end
params = add_default( params, 'use_signal', 'Position');
params = add_default( params, 'pos_dist_thr', 2.0 );
params = add_default( params, 'vel_dist_thr', 10.0 );
params = add_default( params, 'method', 'energy' );
params = add_default( params, 'plot_type', 'no' );

% set distance threshold according according to type of signal (Pos or Vel)
switch params.use_signal,
    case 'Velocity',
        params.dist_thr = params.vel_dist_thr;
    case 'Position'
        params.dist_thr = params.pos_dist_thr;
    otherwise,
        error('mmm? stragne .use_signal')
end



if ~strcmp( params.plot_type, 'no' ),
    params.plot = 1;
else
    params.plot = 0;
end

const = MG_Default_Const;

switch params.use_signal,
    case 'Position', % do nothing
        x = x * const.Ticks2MM;  % change to mm
    case 'Velocity',
        x = vel_acc_with_bfilt( x );
        x = x * const.Ticks2MM;  % change to mm
        x = x * const.Samples_Per_Sec; % change to mm / sec
end

%  [13-05-10] removed thin wavelets, at frequencies above natural movements
%  in the game (<2.5Hz) -  only good for 1min params.MAX_WAVELETS_INDEX  = 512;  %2048
% [08-04-15] Remove this to get full accumalted enegry as in signal

% find best length for 2^N, split into overlapping start & last part
len = length(x);
exact_length = 2 ^ floor( log2( len ) );

for i = 1 : 2,
    if i == 1,
        x2{i} = x( 1 : exact_length );
    else
        x2{i} = x( len - exact_length + 1  : end );
    end
    
    if find(isnan(x2{i})),
        cr2(i) = NaN;
    else
        
        if ~strcmp( params.plot_type, 'no' ),
            subplot(2,1,i)
        end
        
        switch params.method,
            case 'thr',
                cr2(i) = complexity_by_wavelets(x2{i}, params );
            case 'energy',
                cr2(i) = complexity_by_wavelets_by_energy(x2{i}, params );
            otherwise,
                error('strange params.method');
        end
        
        
        if ~strcmp( params.plot_type, 'no' ),
            if i == 1,
                xlabel('time (samples) - first part')
            else
                xlabel('time (samples) - last part')
            end
        end
        
    end
end

switch params.plot_type
    case 'no';
    case 'pause',
        match_axis_in_figure( [2 1] )
        pause
    case 'save',
        match_axis_in_figure( [2 1] )
        drawnow
        my_saveas([],params.lbl, [0 1 1])
end

cr = nanmean( cr2 );